@@ -138,7 +138,8 @@ gnome_db_shell_settings_class_init (GnomeDbShellSettingsClass *klass)
 }
 
 static void
-gnome_db_shell_settings_init (GnomeDbShellSettings *settings, GnomeDbShellSettingsClass *klass)
+gnome_db_shell_settings_init (GnomeDbShellSettings *settings,
+			      GnomeDbShellSettingsClass *klass)
 {
 	GtkWidget *paned;
 	GtkWidget *toolbar;
@@ -158,6 +159,7 @@ gnome_db_shell_settings_init (GnomeDbShellSettings *settings, GnomeDbShellSettin
 	settings->priv->toolbar = gnome_db_shortcut_new ();
 	gtk_paned_add1 (GTK_PANED (paned), settings->priv->toolbar);
 	add_components_to_shortcut (settings);
+	gtk_widget_show (settings->priv->toolbar);
 
 	settings->priv->notebook = gnome_db_new_notebook_widget ();
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (settings->priv->notebook), FALSE);
