@@ -35,6 +35,7 @@
 #include <libgnomedb/gnome-db-window.h>
 #include "gnome-db-defs.h"
 #include "gnome-db-shell.h"
+#include "gnome-db-shell-settings.h"
 #include "gnome-db-shortcut.h"
 #include "gnome-db-summary.h"
 
@@ -70,13 +71,21 @@ static void verb_FileExit (BonoboUIComponent *uic, void *user_data, const char *
 static void verb_HelpAbout (BonoboUIComponent *uic, void *user_data, const char *path);
 static void verb_HelpSubmitBug (BonoboUIComponent *uic, void *user_data, const char *path);
 static void verb_ToolsSettings (BonoboUIComponent *uic, void *user_data, const char *path);
-static void verb_ViewShortcutBar (BonoboUIComponent *uic, void *user_data, const char *path);
+static void toggle_ViewShortcutBar (BonoboUIComponent *uic,
+				    const char *path,
+				    Bonobo_UIComponent_EventType type,
+				    const char *state,
+				    gpointer user_data);
+static void toggle_ViewSummary (BonoboUIComponent *uic,
+				const char *path,
+				Bonobo_UIComponent_EventType type,
+				const char *state,
+				gpointer user_data);
 
 static BonoboUIVerb shell_verbs [] = {
 	BONOBO_UI_VERB ("FileNewDatabase", verb_FileNewDatabase),
 	BONOBO_UI_VERB ("FileNewWindow", verb_FileNewWindow),
 	BONOBO_UI_VERB ("FileExit", verb_FileExit),
-	BONOBO_UI_VERB ("ViewShortcutBar", verb_ViewShortcutBar),
 	BONOBO_UI_VERB ("ToolsSettings", verb_ToolsSettings),
 	BONOBO_UI_VERB ("HelpAbout", verb_HelpAbout),
 	BONOBO_UI_VERB ("HelpSubmitBug", verb_HelpSubmitBug),
@@ -135,9 +144,9 @@ add_components_to_shortcut (GnomeDbShell *shell)
 		/* FIXME */
 	}
 	else {
-		/* start browser by default */
+		/* start database component by default */
 		shortcut_button_clicked_cb (GNOME_DB_SHORTCUT (shell->priv->shortcut),
-					    _("Browser"), GNOME_DB_ID_BROWSER, shell);
+					    _("Database"), GNOME_DB_ID_DATABASE, shell);
 	}
 }
 
@@ -146,6 +155,7 @@ setup_window (GnomeDbShell *shell)
 {
 	GtkWidget *box;
 	gchar *title;
+	BonoboUIComponent *uic;
 
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 
@@ -165,18 +175,11 @@ setup_window (GnomeDbShell *shell)
 
 	shell->priv->workarea = gtk_hpaned_new ();
 	shell->priv->shortcut = gnome_db_shortcut_new ();
-	if (gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT)) {
-		gtk_widget_show (shell->priv->shortcut);
-		shell->priv->show_shortcut = TRUE;
-	}
-	else
-		shell->priv->show_shortcut = FALSE;
 
 	gtk_paned_add1 (GTK_PANED (shell->priv->workarea), shell->priv->shortcut);
 
 	box = gnome_db_new_vbox_widget (FALSE, 0);
 	shell->priv->summary = gnome_db_summary_new ();
-	gtk_widget_show (shell->priv->summary);
 	gtk_box_pack_start (GTK_BOX (box), shell->priv->summary, FALSE, TRUE, 0);
 
 	shell->priv->notebook = gnome_db_new_notebook_widget ();
@@ -186,12 +189,48 @@ setup_window (GnomeDbShell *shell)
 	gtk_box_pack_start (GTK_BOX (box), shell->priv->notebook, TRUE, TRUE, 0);
 	gtk_paned_add2 (GTK_PANED (shell->priv->workarea), box);
 
-	gtk_widget_show_all (shell->priv->workarea);
+	gtk_widget_show (shell->priv->workarea);
 	gnome_db_window_set_contents (GNOME_DB_WINDOW (shell->priv->window),
 				      shell->priv->workarea);
 	gnome_db_window_show (GNOME_DB_WINDOW (shell->priv->window));
 
 	add_components_to_shortcut (shell);
+
+	/* load state of window from configuration */
+	uic = gnome_db_window_get_ui_component (shell->priv->window);
+
+	if (gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT) ||
+	    !gda_config_has_key (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT)) {
+		gtk_widget_show (shell->priv->shortcut);
+		shell->priv->show_shortcut = TRUE;
+		bonobo_ui_component_set_prop (uic, "/commands/ViewShortcutBar",
+					      "state", "1", NULL);
+	}
+	else {
+		gtk_widget_hide (shell->priv->shortcut);
+		shell->priv->show_shortcut = FALSE;
+		bonobo_ui_component_set_prop (uic, "/commands/ViewShortcutBar",
+					      "state", "0", NULL);
+	}
+
+	if (gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY) ||
+	    !gda_config_has_key (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY)) {
+		gtk_widget_show (shell->priv->summary);
+		shell->priv->show_summary = TRUE;
+		bonobo_ui_component_set_prop (uic, "/commands/ViewSummary",
+					      "state", "1", NULL);
+	}
+	else {
+		gtk_widget_hide (shell->priv->summary);
+		shell->priv->show_summary = FALSE;
+		bonobo_ui_component_set_prop (uic, "/commands/ViewSummary",
+					      "state", "0", NULL);
+	}
+
+	bonobo_ui_component_add_listener (uic, "ViewShortcutBar",
+					  toggle_ViewShortcutBar, shell);
+	bonobo_ui_component_add_listener (uic, "ViewSummary",
+					  toggle_ViewSummary, shell);
 }
 
 /*
@@ -217,6 +256,17 @@ config_changed_cb (const gchar *path, gpointer user_data)
 			shell->priv->show_shortcut = FALSE;
 		}
 	}
+	else if (!strcmp (path, GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY)) {
+		/* hide/show summary */
+		if (gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY)) {
+			gtk_widget_show (shell->priv->summary);
+			shell->priv->show_summary = TRUE;
+		}
+		else {
+			gtk_widget_hide (shell->priv->summary);
+			shell->priv->show_summary = FALSE;
+		}
+	}
 }
 
 static void
@@ -309,15 +359,20 @@ verb_HelpAbout (BonoboUIComponent *uic, void *user_data, const char *path)
 		"Gerhard Dieringer <gdieringer@compuserve.com>",
                 NULL
         };
-
         GtkWidget *dialog;
+	GnomeDbShell *shell = (GnomeDbShell *) user_data;
+
+	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 
         dialog = gnome_about_new (_("GNOME-DB"), VERSION,
                                   _("Copyright 2001, The GNOME Foundation"),
                                   _("GNOME Database front-end"),
                                   authors, NULL, NULL, NULL);
-        gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), shell->priv->window);
+	g_signal_connect (G_OBJECT (dialog), "destroy",
+			  G_CALLBACK (gtk_widget_destroyed), &dialog);
+
+	gtk_widget_show (dialog);
 }
 
 static void
@@ -328,65 +383,75 @@ verb_HelpSubmitBug (BonoboUIComponent *uic, void *user_data, const char *path)
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 }
 
-static void
-ToolsSettings_close_button_cb (GtkButton *button, gpointer user_data)
-{
-	GnomeDbWindow *window = (GnomeDbWindow *) user_data;
-
-	g_return_if_fail (GNOME_DB_IS_WINDOW (window));
-	gnome_db_window_close (window);
-}
-
 static void
 verb_ToolsSettings (BonoboUIComponent *uic, void *user_data, const char *path)
 {
-	GnomeDbWindow *window;
+	GtkWidget *dialog;
 	GtkWidget *settings;
-	GtkWidget *box;
-	GtkWidget *separator;
-	GtkWidget *bbox;
-	GtkWidget *button;
 	GnomeDbShell *shell = (GnomeDbShell *) user_data;
 
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 
 	/* create the dialog */
-	window = gnome_db_window_new (_("Settings"), NULL, NULL, NULL, NULL);
-	gnome_window_icon_set_from_file (
-		GTK_WINDOW (window),
-		GNOME_DB_PIXMAPDIR "/gnome-db.png");
+	dialog = gtk_dialog_new_with_buttons (
+		_("Settings"),
+		GTK_WINDOW (shell->priv->window), 0,
+		GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
+		NULL);
+	gnome_window_icon_set_from_file (GTK_WINDOW (dialog),
+					 GNOME_DB_PIXMAPDIR "/gnome-db.png");
 
-	box = gnome_db_new_vbox_widget (FALSE, 0);
 	settings = gnome_db_shell_settings_new (shell);
-	gtk_box_pack_start (GTK_BOX (box), settings, TRUE, TRUE, 0);
-
-	separator = gnome_db_new_hseparator_widget ();
-	gtk_box_pack_start (GTK_BOX (box), separator, FALSE, TRUE, 2);
-
-	bbox = gnome_db_new_hbutton_box_widget ();
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_END);
-	gtk_box_pack_start (GTK_BOX (box), bbox, FALSE, TRUE, 0);
-	button = gnome_db_new_button_widget_from_stock (GTK_STOCK_CLOSE);
-	g_signal_connect (G_OBJECT (button), "clicked",
-			  G_CALLBACK (ToolsSettings_close_button_cb), window);
-	gtk_box_pack_end (GTK_BOX (bbox), button, FALSE, TRUE, 0);
+	gtk_widget_show (settings);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), settings, TRUE, TRUE, 0);
 
 	/* show the dialog */
-	gnome_db_window_set_contents (window, box);
-	gnome_db_window_show (window);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 }
 
 static void
-verb_ViewShortcutBar (BonoboUIComponent *uic, void *user_data, const char *path)
+toggle_ViewShortcutBar (BonoboUIComponent *uic,
+			const char *path,
+			Bonobo_UIComponent_EventType type,
+			const char *state,
+			gpointer user_data)
 {
+	gboolean show;
 	GnomeDbShell *shell = (GnomeDbShell *) user_data;
 
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 
-	if (shell->priv->show_shortcut)
-		gnome_db_shell_hide_shortcut (shell);
-	else
+	if (type != Bonobo_UIComponent_STATE_CHANGED)
+		return;
+
+	show = atoi (state);
+	if (show)
 		gnome_db_shell_show_shortcut (shell);
+	else
+		gnome_db_shell_hide_shortcut (shell);
+}
+
+static void
+toggle_ViewSummary (BonoboUIComponent *uic,
+		    const char *path,
+		    Bonobo_UIComponent_EventType type,
+		    const char *state,
+		    gpointer user_data)
+{
+	gboolean show;
+	GnomeDbShell *shell = (GnomeDbShell *) user_data;
+
+	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
+
+	if (type != Bonobo_UIComponent_STATE_CHANGED)
+		return;
+
+	show = atoi (state);
+	if (show)
+		gnome_db_shell_show_summary (shell);
+	else
+		gnome_db_shell_hide_summary (shell);
 }
 
 /*
@@ -445,7 +510,7 @@ gnome_db_shell_init (GnomeDbShell *shell, GnomeDbShellClass *klass)
 
 	/* add a listener for configuration changes */
 	shell->priv->config_listener_id = gda_config_add_listener (
-		GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT,
+		GNOME_DB_SHELL_CONFIG_SECTION_SHELL,
 		(GdaConfigListenerFunc) config_changed_cb,
 		shell);
 }
@@ -458,14 +523,14 @@ gnome_db_shell_finalize (GObject *object)
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 
 	/* free memory */
-	gda_config_remove_listener (shell->priv->config_listener_id);
-
 	gnome_db_window_close (GNOME_DB_WINDOW (shell->priv->window));
 	shell->priv->window = NULL;
 
 	g_list_free (shell->priv->activated_components);
 	shell->priv->activated_components = NULL;
 
+	gda_config_remove_listener (shell->priv->config_listener_id);
+
 	g_free (shell->priv);
 	shell->priv = NULL;
 
@@ -473,9 +538,9 @@ gnome_db_shell_finalize (GObject *object)
 }
 
 BONOBO_TYPE_FUNC_FULL (GnomeDbShell,
-			 GNOME_Database_UIShell,
-			 PARENT_TYPE,
-			 gnome_db_shell)
+		       GNOME_Database_UIShell,
+		       PARENT_TYPE,
+		       gnome_db_shell)
 
 /**
  * gnome_db_shell_new
@@ -583,3 +648,17 @@ gnome_db_shell_hide_shortcut (GnomeDbShell *shell)
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 	gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT, FALSE);
 }
+
+void
+gnome_db_shell_show_summary (GnomeDbShell *shell)
+{
+	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
+	gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY, TRUE);
+}
+
+void
+gnome_db_shell_hide_summary (GnomeDbShell *shell)
+{
+	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
+	gda_config_set_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SUMMARY, FALSE);
+}
